@@ -44,6 +44,10 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 
+#include <glib.h>
+#include <glib/gstdio.h>
+#include <gio/gio.h>
+
 #include <libxfce4util/libxfce4util.h>
 #include <xfconf/xfconf.h>
 #include <libxfce4ui/libxfce4ui.h>
@@ -172,6 +176,26 @@ static gchar *xfdesktop_settings_get_backdrop_image(AppearancePanel *panel);
 
 
 
+static const gchar *
+system_data_lookup (void)
+{
+    const gchar * const * dirs;
+    gchar *path = NULL;
+    guint i;
+
+    dirs = g_get_system_data_dirs ();
+    for (i = 0; path == NULL && dirs[i] != NULL; ++i) {
+        path = g_build_path (G_DIR_SEPARATOR_S, dirs[i], "backgrounds", NULL);
+        if (g_path_is_absolute (path) && g_file_test (path, G_FILE_TEST_IS_DIR))
+            return path;
+
+        g_free (path);
+        path = NULL;
+    }
+
+    return path;
+}
+
 static void
 xfdesktop_settings_free_pdata(gpointer data)
 {
@@ -1033,6 +1057,8 @@ xfdesktop_spin_icon_size_timer(GtkSpinButton *button)
                             DESKTOP_ICONS_ICON_SIZE_PROP,
                             gtk_spin_button_get_value(button));
 
+    g_object_set_data(G_OBJECT(button), "timer-id", NULL);
+
     return FALSE;
 }
 
@@ -1700,6 +1726,9 @@ xfdesktop_settings_dialog_setup_tabs(GtkBuilder *main_gxml,
     WnckScreen *wnck_screen;
     XfconfChannel *channel = panel->channel;
     GdkColor color;
+    const gchar *path;
+    GFile *file;
+    gchar *uri_path;
 
     TRACE("entering");
 
@@ -1729,6 +1758,7 @@ xfdesktop_settings_dialog_setup_tabs(GtkBuilder *main_gxml,
     chk_custom_font_size = GTK_WIDGET(gtk_builder_get_object(main_gxml,
                                                              "chk_custom_font_size"));
     spin_font_size = GTK_WIDGET(gtk_builder_get_object(main_gxml, "spin_font_size"));
+    gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin_font_size), 12);
 
     /* single click */
     chk_single_click = GTK_WIDGET(gtk_builder_get_object(main_gxml,
@@ -1837,6 +1867,20 @@ xfdesktop_settings_dialog_setup_tabs(GtkBuilder *main_gxml,
     gtk_file_filter_add_pixbuf_formats(filter);
     gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(panel->btn_folder), filter);
 
+    /* Get default wallpaper folder */
+    path = system_data_lookup ();
+
+    if (path != NULL) {
+        file = g_file_new_for_path (path);
+        uri_path = g_file_get_uri (file);
+
+        gtk_file_chooser_add_shortcut_folder_uri (GTK_FILE_CHOOSER(panel->btn_folder),
+                                                  uri_path, NULL); 
+
+        g_free (uri_path);
+        g_object_unref (file);
+    }
+
     /* Image and color style options */
     panel->image_style_combo = GTK_WIDGET(gtk_builder_get_object(appearance_gxml, "combo_style"));
 
@@ -2054,7 +2098,7 @@ main(int argc, char **argv)
 
     if(G_UNLIKELY(opt_version)) {
         g_print("%s %s (Xfce %s)\n\n", G_LOG_DOMAIN, VERSION, xfce_version_string());
-        g_print("%s\n", "Copyright (c) 2004-2013");
+        g_print("%s\n", "Copyright (c) 2004-2015");
         g_print("\t%s\n\n", _("The Xfce development team. All rights reserved."));
         g_print(_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
         g_print("\n");
